.. warning::
   请确保本地python环境和PIP工具能够正常使用。

Log包介绍和使用
....................

**rayvision_log** 保存渲染流程信息，主要是用自定义日志配置来初始化`logging`模块。


Log演示demo
-------------

学习的最好方法就是参考例子，`rayvision_log` 也不例外，我们也提供了下面的一个使用 **demo** 样例供您参考::

    import logging
    from rayvision_log import init_logger

    package_name = 'mylog'
    init_logger(package_name)
    logging.info('test')


日志路径
--------

1. 默认路径
   Mac OS X:   ~/Library/Logs/<AppName>/Logs/<username>/<hostname>.log
   Unix:       ~/.cache/<AppName>/log/Logs/<username>/<hostname>.log
   Vista:      C:\Users\<username>\AppData\Local\<AppAuthor>\<AppName>\Logs\<username>\<hostname>.log

2. 自定义路径
   - 定义参数： ``RAYVISION_LOG_ROOT = "xxxx"``
   - 将 **RAYVISION_LOG_ROOT** 设置为系统环境变量
   - 日志路径将会保存在 **RAYVISION_LOG_ROOT** 文件夹下
